@@ -1,5 +1,5 @@
 package Curio;
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Curio::Declare qw();
 use Curio::Role qw();
@@ -508,7 +508,7 @@ system.
 Curio is designed to make it cheap to retrieve Curio objects and the
 underlying resources.  Take advantage of this.  Don't pass around your
 resource objects or put them in attributes.  Instead, when you need
-them, get the from your Curio classes.
+them, get them from your Curio classes.
 
 If your Curio class supports keys, then passing around the key that
 you want particular code to be using, rather than the Curio object or
@@ -619,6 +619,7 @@ this distribution would not exist.
 =head1 AUTHORS
 
     Aran Clary Deltac <bluefeet@gmail.com>
+    Mohammad S Anwar <mohammad.anwar@yahoo.com>
 
 =head1 COPYRIGHT AND LICENSE
 
